@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Administration Scripts
-# Copyright (c) 2008-2016 Hive Solutions Lda.
+# Copyright (c) 2008-2017 Hive Solutions Lda.
 #
 # This file is part of Hive Administration Scripts.
 #
@@ -31,7 +31,7 @@ __revision__ = "$LastChangedRevision$"
 __date__ = "$LastChangedDate$"
 """ The last change date of the module """
 
-__copyright__ = "Copyright (c) 2008-2016 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2017 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -150,6 +150,51 @@ BROWSER_PREFIXES = (
 """ The sequence that defines the complete set of accepted
 browser prefixes for the stylesheet usage """
 
+PREFIXED_NAMES = (
+    "animation",
+    "animation-delay",
+    "animation-duration",
+    "animation-name",
+    "appearance",
+    "backface-visibility",
+    "background-clip",
+    "border-bottom-left-radius",
+    "border-bottom-right-radius",
+    "border-radius",
+    "border-top-left-radius",
+    "border-top-right-radius",
+    "box-shadow",
+    "box-sizing",
+    "column-count",
+    "column-gap",
+    "filter",
+    "font-smoothing",
+    "hyphens",
+    "opacity",
+    "osx-font-smoothing",
+    "outline",
+    "overflow-scrolling",
+    "perspective",
+    "print-color-adjust",
+    "tab-size",
+    "highlight-color",
+    "fill-color",
+    "text-shadow",
+    "touch-callout",
+    "transform",
+    "transform-origin",
+    "transform-style",
+    "transition",
+    "transition-delay",
+    "transition-duration",
+    "transition-property",
+    "transition-timing-function",
+    "user-select",
+    "zoom"
+)
+""" The complete set of property names that should be prefixed
+with proper browser prefixes (complex properties) """
+
 def get_property_index(property_line, property_order, line_number):
     """
     Retrieves the index for the property specified in the provided property
@@ -285,7 +330,7 @@ def process_property_lines(
     :param avoid_empty: If the empty lines should avoid any
     kind of processing (extra errors may occur).
     :type indentation: int
-    :param identation: The level of indentation to be used for the processing
+    :param indentation: The level of indentation to be used for the processing
     of the various property lines, this value is going to be used in the
     operation of pre-pending spaced to the property rules.
     :rtype: List
@@ -298,6 +343,10 @@ def process_property_lines(
     processed_property_lines = [process_property_line(property_line, line_number, indentation)\
         for property_line in property_lines if not avoid_empty or property_line.strip()]
 
+    # runs the initial process of simplifying the property lines
+    # by running the various rules for the current property lines
+    processed_property_lines = process_rules_g(processed_property_lines, line_number, indentation)
+
     # runs an extra step to check for any duplicated line
     # in the set of processed property lines
     check_duplicates(processed_property_lines, line_number)
@@ -305,6 +354,53 @@ def process_property_lines(
     # returns the processed property lines
     return processed_property_lines
 
+def process_rules_g(property_lines, line_number, indentation):
+    # creates the dictionary that is going to hold the multiple
+    # properly lines indexed by their name
+    property_lines_m = dict()
+
+    # iterates over the complete set of property lines to split
+    # them into name and value and populate the map of properties
+    for property_line in property_lines:
+        parts = property_line.split(":", 1)
+        if len(parts) == 1: parts += [""]
+        name, value = parts
+        name = name.strip()
+        value = value.strip()
+        property_lines_m[name] = value
+
+    # runs the complete set of global rules against the property
+    # lines map so that it gets properly updated, running then the
+    # re-creation of the properly lines list (should re-run ordering)
+    process_rule_all_g(property_lines_m)
+    property_lines = ["%s%s: %s" % (indentation * " " * 4, name, value) for name, value in legacy.items(property_lines_m)]
+    return property_lines
+
+def process_rule_all_g(property_lines_m):
+    process_rule_prefixes_g(property_lines_m)
+
+def process_rule_prefixes_g(property_lines_m):
+    prefixes = [""] + list(BROWSER_PREFIXES)
+
+    for name in PREFIXED_NAMES:
+        exists = False
+
+        for prefix in prefixes:
+            name_p = prefix + "-" + name if prefix else name
+            if not name_p in property_lines_m: continue
+            exists = True
+            break
+
+        if not exists: continue
+
+        value = property_lines_m[name_p]
+
+        for prefix in prefixes:
+            name_p = prefix + "-" + name if prefix else name
+            property_lines_m[name_p] = value
+
+    return property_lines_m
+
 def check_duplicates(property_lines, line_number):
     # retrieves the complete set of names for the rules, this is
     # going to be used as the base unit for duplicate checking
@@ -387,11 +483,13 @@ def rule_zero_to_none(name, value):
 def rule_one_to_multiple(name, value):
     parts = value.split()
     if not len(parts) == 1: return
+    if value in ("initial", "inherit"): return
     return "%s: %s %s %s %s;" % (name, value, value, value, value)
 
 def rule_two_to_multiple(name, value):
     parts = value.split()
     if not len(parts) == 2: return
+    if value in ("initial", "inherit"): return
     return "%s: %s %s;" % (name, value, value)
 
 def process_rules(property_line, line_number):
@@ -698,6 +796,7 @@ def cleanup_properties(
                 indentation = open_rule_count + 1,
                 avoid_empty = fix_extra_newlines
             )
+            property_lines = sorted(property_lines, key = get_comparison_key)
 
             # writes the lines to the buffer, considering the windows newline
             # and then writes the line
@@ -1047,3 +1146,5 @@ def main():
 
 if __name__ == "__main__":
     main()
+else:
+    __path__ = []
