@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Administration Scripts
-# Copyright (c) 2008-2016 Hive Solutions Lda.
+# Copyright (c) 2008-2017 Hive Solutions Lda.
 #
 # This file is part of Hive Administration Scripts.
 #
@@ -31,7 +31,7 @@ __revision__ = "$LastChangedRevision$"
 __date__ = "$LastChangedDate$"
 """ The last change date of the module """
 
-__copyright__ = "Copyright (c) 2008-2016 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2017 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -192,6 +192,7 @@ configurations = (
             "display",
             "elevation",
             "empty-cells",
+            "fill",
             "filter",
             "-o-filter",
             "-ms-filter",
@@ -209,6 +210,7 @@ configurations = (
             "-moz-font-smoothing",
             "-khtml-font-smoothing",
             "-webkit-font-smoothing",
+            "font-stretch",
             "font-style",
             "font-variant",
             "font-weight",
@@ -236,7 +238,13 @@ configurations = (
             "max-width",
             "min-height",
             "min-width",
+            "object-fit",
             "opacity",
+            "-o-opacity",
+            "-ms-opacity",
+            "-moz-opacity",
+            "-khtml-opacity",
+            "-webkit-opacity",
             "orphans",
             "osx-font-smoothing",
             "-o-osx-font-smoothing",
@@ -249,7 +257,18 @@ configurations = (
             "outline-style",
             "outline-width",
             "outline",
+            "-o-outline",
+            "-ms-outline",
+            "-moz-outline",
+            "-khtml-outline",
+            "-webkit-outline",
             "overflow",
+            "overflow-scrolling",
+            "-o-overflow-scrolling",
+            "-ms-overflow-scrolling",
+            "-moz-overflow-scrolling",
+            "-khtml-overflow-scrolling",
+            "-webkit-overflow-scrolling",
             "overflow-x",
             "overflow-y",
             "padding-bottom",
@@ -292,9 +311,15 @@ configurations = (
             "speech-rate",
             "src",
             "stress",
+            "stroke",
+            "stroke-dasharray",
+            "stroke-dashoffset",
             "tab-size",
             "-o-tab-size",
+            "-ms-tab-size",
             "-moz-tab-size",
+            "-khtml-tab-size",
+            "-webkit-tab-size",
             "table-layout",
             "tap-highlight-color",
             "-o-tap-highlight-color",
@@ -362,6 +387,12 @@ configurations = (
             "-moz-transition-duration",
             "-khtml-transition-duration",
             "-webkit-transition-duration",
+            "transition-property",
+            "-o-transition-property",
+            "-ms-transition-property",
+            "-moz-transition-property",
+            "-khtml-transition-property",
+            "-webkit-transition-property",
             "transition-timing-function",
             "-o-transition-timing-function",
             "-ms-transition-timing-function",
@@ -382,10 +413,17 @@ configurations = (
             "white-space",
             "widows",
             "width",
+            "will-change",
             "word-break",
             "word-spacing",
             "word-wrap",
-            "z-index"
+            "z-index",
+            "zoom",
+            "-o-zoom",
+            "-ms-zoom",
+            "-moz-zoom",
+            "-khtml-zoom",
+            "-webkit-zoom"
         ),
         "rules_skip" : (
             "@-",
